@@ -12,14 +12,14 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 bl_info = {
-    "name" : "OpenMoCap",
+    "name" : "FreeMoCap",
     "author" : "Jonathan Samir Matthis",
     "description" : "",
     "blender" : (2, 80, 0),
     "version" : (0, 0, 1),
     "location" : "",
     "warning" : "",
-    "category" : "omc"
+    "category" : "fmc"
 }
 
 import bpy
@@ -31,20 +31,11 @@ def register():
     
     #define 'custom properties' - https://youtu.be/9fuFDHR-UkE 
 
-    bpy.types.Scene.fmc_session_config_path = bpy.props.StringProperty(
-        name = 'FMC Session Config File Path',
+    bpy.types.Scene.fmc_session_path = bpy.props.StringProperty(
+        name = 'FMC Session Path',
         subtype= 'FILE_PATH'
     )
 
-    bpy.types.Scene.omc_session_config_fname = bpy.props.StringProperty(
-        name = 'FMC Session Config File',
-        subtype= 'FILE_NAME'
-    )
-
-    bpy.types.Scene.fmc_session_id = bpy.props.StringProperty(
-        name = 'FMC Session ID',
-    )
-
     auto_load.register()
     print('registering FreeMoCap Addon')
 
